summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorShulhan <ms@kilabit.info>2024-03-21 17:47:07 +0700
committerShulhan <ms@kilabit.info>2024-03-21 17:47:07 +0700
commitcee16b8ead859b1ac372d6153d03a058d4e7ae82 (patch)
treebf76b4538ad837a2d4f1dce2a86c3c690bb650fa
parent547c4b59811091bd613564a2df5b8f3ebc72bd8f (diff)
downloadpakakeh.go-cee16b8ead859b1ac372d6153d03a058d4e7ae82.tar.xz
all: rename the root file to new package name
-rw-r--r--pakakeh.go (renamed from share.go)4
1 files changed, 2 insertions, 2 deletions
diff --git a/share.go b/pakakeh.go
index 404ef17b..d79dda25 100644
--- a/share.go
+++ b/pakakeh.go
@@ -2,9 +2,9 @@
// Use of this source code is governed by a BSD-style
// license that can be found in the LICENSE file.
// Package share contains public APIs and libraries for working with Go
// language, and tools written in Go.
-package share
+package pakakeh
var (
// Version of this module.
@@ -2,9 +2,9 @@
// Use of this source code is governed by a BSD-style
// license that can be found in the LICENSE file.
-// Package share contains public APIs and libraries for working with Go
+// Package pakakeh contains public APIs and libraries for working with Go
// language, and tools written in Go.